==> k3d_0.4.3.0.orig.tar.gz: k3d-0.4.3.0/k3dsdk/result.h <==
#ifndef K3DSDK_RESULT_H
#define K3DSDK_RESULT_H

// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
		\brief Declares void and Glib-like assert/return functions
		\author Romain Behar (romainbehar@yahoo.com)
		\author Tim Shead (tshead@k-3d.com)
*/

#include "log.h"
#include <iostream>

#define k3d_file_reference() __FILE__ << " line " << __LINE__ << ":"

#define assert_not_reached() \
	do \
		{ \
			std::cerr << error << k3d_file_reference() << " should not be reached" << std::endl; \
		} \
	while(0)

#define assert_warning(expr) \
	do \
		{ \
			if(!(expr)) \
				{ \
					std::cerr << warning << k3d_file_reference() << " assertion `" << #expr << "' failed" << std::endl; \
				} \
		} \
	while(0)

#define return_if_fail(expr) \
	do \
		{ \
			if(!(expr)) \
				{ \
					std::cerr << error << k3d_file_reference() << " assertion `" << #expr << "' failed" << std::endl; \
					return; \
				} \
		} \
	while(0)

#define return_val_if_fail(expr, val) \
	do \
		{ \
			if(!(expr)) \
				{ \
					std::cerr << error << k3d_file_reference() << " assertion `" << #expr << "' failed" << std::endl; \
					return val; \
				} \
		} \
	while(0)

#endif // !K3DSDK_RESULT_H

==> k3d_0.5.0.35.orig.tar.gz: k3d-0.5.0.35/k3dsdk/result.h <==
#ifndef K3DSDK_RESULT_H
#define K3DSDK_RESULT_H

// K-3D
// Copyright (c) 1995-2004, Timothy M. Shead
//
// Contact: tshead@k-3d.com
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/** \file
		\brief Declares void and Glib-like assert/return functions
		\author Romain Behar (romainbehar@yahoo.com)
		\author Tim Shead (tshead@k-3d.com)
*/

#include "log.h"
#include <iostream>

#define assert_not_reached() \
	do \
		{ \
			k3d::log() << k3d::error << k3d_file_reference << ": should not be reached" << std::endl; \
		} \
	while(0)

#define assert_not_implemented() \
	do \
		{ \
			k3d::log() << k3d::error << k3d_file_reference << ": is not implemented" << std::endl; \
		} \
	while(0)

#define assert_deprecated() \
	do \
		{ \
			k3d::log() << k3d::warning << k3d_file_reference << ": is deprecated" << std::endl; \
		} \
	while(0)

#define assert_critical(expr) \
	do \
		{ \
			if(!(expr)) \
				{ \
					k3d::log() << k3d::critical << k3d_file_reference << ": assertion `" << #expr << "' failed" << std::endl; \
				} \
		} \
	while(0)

#define assert_error(expr) \
	do \
		{ \
			if(!(expr)) \
				{ \
					k3d::log() << k3d::error << k3d_file_reference << ": assertion `" << #expr << "' failed" << std::endl; \
				} \
		} \
	while(0)

#define assert_warning(expr) \
	do \
		{ \
			if(!(expr)) \
				{ \
					k3d::log() << k3d::warning << k3d_file_reference << ": assertion `" << #expr << "' failed" << std::endl; \
				} \
		} \
	while(0)

#define return_if_fail(expr) \
	do \
		{ \
			if(!(expr)) \
				{ \
					k3d::log() << k3d::error << k3d_file_reference << ": assertion `" << #expr << "' failed" << std::endl; \
					return; \
				} \
		} \
	while(0)

#define return_val_if_fail(expr, val) \
	do \
		{ \
			if(!(expr)) \
				{ \
					k3d::log() << k3d::error << k3d_file_reference << ": assertion `" << #expr << "' failed" << std::endl; \
					return val; \
				} \
		} \
	while(0)

#endif // !K3DSDK_RESULT_H
